Exception: InstacartApi::UnknownOperationError
- Defined in:
- lib/instacart_api/errors.rb
Overview
A request for an operation we have no persisted-query hash for. Usually means the captured hashes are stale — re-run the capture script.
A request for an operation we have no persisted-query hash for. Usually means the captured hashes are stale — re-run the capture script.